@@ -2,8 +2,8 @@ from __future__ import annotations
 
 import argparse
 
-import pwndbg.aglib.arch
-import pwndbg.aglib.regs
+import pwndbg.aglib
+import pwndbg.aglib.proc
 import pwndbg.commands
 from pwndbg.color import context
 from pwndbg.commands import CommandCategory
@@ -15,12 +15,12 @@ parser.add_argument(
 )
 
 
-@pwndbg.commands.ArgparsedCommand(
+@pwndbg.commands.Command(
     parser,
     aliases=["xpsr", "pstate"],
     category=CommandCategory.REGISTER,
 )
-@pwndbg.commands.OnlyWithArch(["arm", "armcm", "aarch64"])
+@pwndbg.aglib.proc.OnlyWithArch(["arm", "armcm", "aarch64"])
 @pwndbg.commands.OnlyWhenRunning
 def cpsr(cpsr_value=None) -> None:
     reg = "xpsr" if pwndbg.aglib.arch.name == "armcm" else "cpsr"
@@ -29,6 +29,6 @@ def cpsr(cpsr_value=None) -> None:
     if cpsr_value is not None:
         reg_val = cpsr_value
     else:
-        reg_val = getattr(pwndbg.aglib.regs, reg)
+        reg_val = pwndbg.aglib.regs.read_reg(reg)
 
     print(f"{reg} {context.format_flags(reg_val, reg_flags)}")
